#########
# Author:        ajb
# Maintainer:    $Author: gq1 $
# Created:       2008-06-10
# Last Modified: $Date: 2008-11-06 15:46:38 +0000 (Thu, 06 Nov 2008) $
# Id:            $Id: swift_output.pm 3386 2008-11-06 15:46:38Z gq1 $
# Source:        $Source: /repos/cvs/webcore/SHARED_docs/cgi-bin/docrep,v $
# $HeadURL: svn+ssh://svn.internal.sanger.ac.uk/repos/svn/new-pipeline-dev/npg-qc/tags/release-4.0/lib/npg_qc/api/process/swift_output.pm $
#

package npg_qc::api::process::swift_output;
use strict;
use Class::Std;
use warnings;
use Carp;
use base qw(npg_qc::api::process);
use Readonly;

our $VERSION = do { my ($r) = q$LastChangedRevision: 3386 $ =~ /(\d+)/mx; $r; };

{
  ## no critic
  my %file_of     :ATTR( :get<file>, :set<file> );
  my %position_of :ATTR( :get<position>, :set<position> );
  my %id_run_of   :ATTR( :get<id_run>, :set<id_run> );
  my %tile_of     :ATTR( :get<tile>, :set<tile> );
  ## use critic

  sub process_file {
    my ($self, $file_url) = @_;
    my $capture;
    ($capture) = $file_url =~ /swift_(\d+)_runreport.txt/xms;
    $self->set_tile($capture);
    ($capture) = $file_url =~ /_0*(\d+)\/Swift/xms;
    $self->set_id_run($capture);
    ($capture) = $file_url =~ /L0*(\d+)\/Output/xms;
    $self->set_position($capture);
    my $file = $self->read_file($file_url);
    $self->set_file($file);
    my ($swift_report)           = $self->get_file() =~ /(PF\ Bases.*?)Errors/xms;
    my ($pf_errors)              = $self->get_file() =~ /Errors\ across\ cycle\ for\ pf\ reads\n(.*?)Errors/xms;
    my ($npf_errors)             = $self->get_file() =~ /Errors\ across\ cycle\ for\ nonpf\ reads\n(.*?)Average/xms;
    my ($ave_all_intensities)    = $self->get_file() =~ /Average\ of\ \*ALL\*\ intensities\ per\ Cycle\ per\ base\nA\ C\ G\ T\n(.*?)Average/xms;
    my ($ave_called_intensities) = $self->get_file() =~ /Average\ of\ \*CALLED\*\ intensities\ per\ Cycle\ per\ base\nA\ C\ G\ T\n(.*)/xms;

    $self->report($swift_report);
    $self->errors('pf_errors', $pf_errors);
    $self->errors('npf_errors', $npf_errors);
    $self->intensities('average_all_intensities', $ave_all_intensities);
    $self->intensities('average_called_intensities', $ave_called_intensities);
    return;
  }

  sub report {
    my ($self, $report) = @_;
    my @report_lines = split /\n/xms, $report;
    my $swift_report = {};
    my $xml = q{<?xml version="1.0" encoding="utf-8"?><swift_report id_run="}.$self->get_id_run().q{" tile="}.$self->get_tile().q{" position="}.$self->get_position().q{" };
    foreach my $line (@report_lines) {
      next if ($line eq q{});
      my ($key, $value) = split /:/xms, $line;
      ($value) = $value =~ /(\d+)/xms;
      $key =~ s/\ /_/gxms;
      $key = lc$key;
      $swift_report->{$key} = $value;
      $xml .= qq{$key="$value" };
    }
    $xml .= q{/>};
    return $xml;
  }

  sub errors {
    my ($self, $pf, $errors) = @_;
    my @error_lines = split /\n/xms, $errors;
    my $xml = qq{<?xml version="1.0" encoding="utf-8"?><$pf id_run="}.$self->get_id_run().q{" tile="}.$self->get_tile().q{" position="}.$self->get_position().q{"><cycles>};
    foreach my $line (@error_lines) {
      last if ($line eq q{});
      my ($cycle, $error) = split q{ }, $line;
      $cycle++;
      $xml .= qq{<cycle number="$cycle" errors="$error" />}
    }
    $xml .= qq{</cycles></$pf>};
    return $xml;
  }

  sub intensities {
    my ($self, $all, $intensities) = @_;
    my @intensity_lines = split /\n/xms, $intensities;
    my $xml = qq{<?xml version="1.0" encoding="utf-8"?><$all id_run="}.$self->get_id_run().q{" tile="}.$self->get_tile().q{" position="}.$self->get_position().q{"><cycles>};
    foreach my $line (@intensity_lines) {
      last if ($line eq q{});
      my ($cycle, $base_a, $c, $g, $t) = split q{ }, $line;
      $cycle++;
      $xml .= qq{<cycle number="$cycle" a="$base_a" c="$c" g="$g" t="$t" />}
    }
    $xml .= qq{</cycles></$all>};
    return $xml;
  }

}

1;
__END__

=head1 NAME

npg_qc::api::process::swift_output

=head1 VERSION

$LastChangedRevision: 3386 $

=head1 SYNOPSIS

  my $oSwiftOutput = npg_qc::api::process::swift_output->new({util => $oUtil});

=head1 DESCRIPTION

Process swift_output files into xml format

=head1 SUBROUTINES/METHODS

=head2 process_file - processes the $full_path_uri_to_file in order to obtain information about rescore, file, position, id_run and tile. stores these

=head2 report

=head2 errors

=head2 intensities

=head1 DIAGNOSTICS

=head1 CONFIGURATION AND ENVIRONMENT

=head1 DEPENDENCIES

strict
warnings
Class::Std
Carp
npg_qc::api::process

=head1 INCOMPATIBILITIES

=head1 BUGS AND LIMITATIONS

=head1 AUTHOR

Andy Brown, E<lt>ajb@sanger.ac.ukE<gt>

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2008 GRL, by Andy Brown

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.4 or,
at your option, any later version of Perl 5 you may have available.

=cut
