#########
# Author:        ajb
# Maintainer:    $Author: gq1 $
# Created:       2008-08-07
# Last Modified: $Date: 2008-11-06 15:46:38 +0000 (Thu, 06 Nov 2008) $
# Id:            $Id: qcal.pm 3386 2008-11-06 15:46:38Z gq1 $
# $HeadURL: svn+ssh://svn.internal.sanger.ac.uk/repos/svn/new-pipeline-dev/npg-qc/tags/release-4.0/lib/npg_qc/model/qcal.pm $
#

package npg_qc::model::qcal;
use strict;
use warnings;
use English qw{-no_match_vars};
use Carp;
use base qw(npg_qc::model);

our $VERSION = do { my ($r) = q$LastChangedRevision: 3386 $ =~ /(\d+)/mx; $r; };

__PACKAGE__->mk_accessors(__PACKAGE__->fields());

sub fields {
  return qw(
            id_qcal
            id_run
            position
            end
            twenty
            twentyfive
            thirty
          );
}

sub greater_than_refactor {
  my ($self, $field) = @_;

  my $query = q{SELECT SUM(?)
                FROM   qcal
                WHERE  id_run = ?};

  my $dbh = $self->util->dbh();
  my $sth = $dbh->prepare($query);
  $sth->execute($field, $self->id_run);

  return $sth->fetchrow_arrayref()->[0];
}

sub greater_than_q_twenty {
  my $self = shift;
  return $self->greater_than_refactor('twenty');
}

sub greater_than_q_twentyfive {
  my $self = shift;
  return $self->greater_than_refactor('twentyfive');
}

sub greater_than_q_thirty {
  my $self = shift;
  return $self->greater_than_refactor('thirty');
}

1;
__END__
=head1 NAME

npg_qc::model::qcal


=head1 VERSION

$LastChangedRevision: 3386 $

=head1 SYNOPSIS

  my $oQcal = npg_qc::model::qcal->new({util => $util});

=head1 DESCRIPTION

=head1 SUBROUTINES/METHODS

=head2 fields - return array of fields, first of which is the primary key

  my $aFields = $oQcal->fields();

=head2 greater_than_q_thirty - returns the number of bases above a q30 value

  my $iGreaterThanQThirty = $oQcal->greater_than_q_thirty();

=head2 greater_than_q_twenty - returns the number of bases above a q20 value

  my $iGreaterThanQTwenty = $oQcal->greater_than_q_twenty();

=head2 greater_than_q_twentyfive - returns the number of bases above a q25 value

  my $iGreaterThanQTwentyfive = $oQcal->greater_than_q_twentyfive();

=head2 greater_than_refactor - refactor of common code from greater_than_q_thirty, greater_than_q_twenty, greater_than_q_twentyfive

=head1 DIAGNOSTICS

=head1 CONFIGURATION AND ENVIRONMENT

=head1 DEPENDENCIES

strict
warnings
npg_qc::model
English
Carp

=head1 INCOMPATIBILITIES

=head1 BUGS AND LIMITATIONS

=head1 AUTHOR

Andy Brown, E<lt>ajb@sanger.ac.ukE<gt>

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2008 GRL, by Andy Brown

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.4 or,
at your option, any later version of Perl 5 you may have available.

=cut
