#########
# Author:        ajb
# Maintainer:    $Author: gq1 $
# Created:       2008-06-10
# Last Modified: $Date: 2008-11-06 15:46:38 +0000 (Thu, 06 Nov 2008) $
# Id:            $Id: errors_by_cycle.pm 3386 2008-11-06 15:46:38Z gq1 $
# Source:        $Source: /repos/cvs/webcore/SHARED_docs/cgi-bin/docrep,v $
# $HeadURL: svn+ssh://svn.internal.sanger.ac.uk/repos/svn/new-pipeline-dev/npg-qc/tags/release-4.0/lib/npg_qc/view/errors_by_cycle.pm $
#

package npg_qc::view::errors_by_cycle;
use strict;
use warnings;
use base qw(npg_qc::view);
use Readonly;
use English qw{-no_match_vars};
use Carp;
use npg_common::image_map;
use npg_common::image::heatmap;
use npg_common::image::graph;

our $VERSION = do { my ($r) = q$LastChangedRevision: 3386 $ =~ /(\d+)/mx; $r; };

Readonly our $WIDTH                => 800;
Readonly our $HEIGHT               => 460;
Readonly our $X_LABEL_SKIP         => 5;
Readonly our $MAX_ERROR_PERCENTAGE => 20;
Readonly our $THUMB_HEIGHT         => 86;
Readonly our $THUMB_WIDTH          => 126;
Readonly our $THUMBNAIL_TILE_WIDTH => 4;

sub list {
  my ($self) = @_;
  return $self->list_refactor();
}

sub list_heatmaps {
  my ($self) = @_;
  return $self->list_refactor();
}

sub list_ave_by_position {
  my ($self) = @_;
  return $self->list_refactor();
}

sub read_ec_scale_png {
  my ($self) = @_;
  return $self->read_scale_png({ orientation => 'horizontal', end_text => '>20', });
}

sub read_heatmap_with_hover_ajax {
  my ($self) = @_;
  my $util      = $self->util();
  my $model     = $self->model();
  my $cgi       = $util->cgi();
  my $cycle_ref = $cgi->param('cycle_ref');
  my ($id_run, $cycle) = split /_/xms, $cycle_ref;
  $model->{id_run} = $id_run;
  $model->cycle($cycle);

  my $data_refs = {
    id_run    => $id_run,
    end       => 1,
    dataset   => q{error_per_tile},
    image_url => $cgi->param('url'),
    id        => q{error_per_tile:} . $id_run . q{:} . $cycle,
    hover_map => 1,
  };


  eval {
    my $end = 1;
    my $cycle_count = $model->cycle_count();

    if ($cycle > $cycle_count) {
      $cycle -= $cycle_count;
      $end = 2;
    }

    $data_refs->{data} = $self->read_heatmap($data_refs);
    foreach my $box (@{$data_refs->{data}}) {
      my $data_information = $box->[-1];
      my $params = q{id_run=} . $id_run . q{&position=} . $data_information->{position} . q{&tile=} . $data_information->{tile} . q{&end=} . $end . q{&cycle=} . $cycle;
      $box->[-1]->{url} = q{#" onClick="open_tile_viewer('/cgi-bin/prodsoft/npg_qc/npg_qc/run_tile/;read_tile_viewer?} . $params .q{');return false;};
    }
    my $image_map_object = npg_common::image_map->new();
    $model->{map} = $image_map_object->render_map($data_refs);
  } or do {
    croak 'Unable to render map: ' . $EVAL_ERROR;
  };

  return 1;
}

sub read_heatmap {
  my ($self, $data_refs)    = @_;
  my $util      = $self->util();
  my $model     = $self->model();
  my $cgi       = $util->cgi();
  my $cycle_ref = $cgi->param('cycle_ref');
  my ($id_run, $cycle) = split /_/xms, $cycle_ref;
  
  $model->{id_run} = $id_run;
  $model->cycle($cycle);
  
  my $thumbnail = $cgi->param('thumb') || q{};
  
  my $dataset = $model->heatmap_data_per_cycle();

  my $heatmap_obj = npg_common::image::heatmap->new({
    data_array => $dataset,
  });
  
  my $png;
  
  my $arg_refs = $thumbnail eq 'true' ? {
                                         vertical       => 1,
                                         tile_width     => $THUMBNAIL_TILE_WIDTH,
                                         gradient_style => 'percentage',
                                        }
               :                        {
                                         vertical       => 1,
                                         gradient_style => 'percentage',
                                        }
               ;
  eval {

    $png = $heatmap_obj->plot_illumina_map($arg_refs);

    1;

  } or do {

    croak $EVAL_ERROR;

  };

  if ($data_refs->{hover_map}) {
    return $heatmap_obj->image_map_reference();
  }

  return $png;

}

sub read_png {
  my ($self)       = @_;
  my $util         = $self->util();
  my $model        = $self->model();
  my $cgi          = $util->cgi();
  my $tile_ref     = $cgi->param('tile_ref');
  my ($id_run, $position, $tile) = split /_/xms, $tile_ref;
  my $thumbnail    = $cgi->param('thumb');
  my $pre_chastity = $cgi->param('pre_chastity');
  my $graph_obj    = npg_common::image::graph->new({util => $util});
  my $type         = 'area';

  $model->{id_run} = $id_run;
  my $data  = $tile && $pre_chastity ? $model->data_for_plot_including_pre_chastity($id_run, $position, $tile)
            : $tile                  ? $model->data_for_plot($id_run, $position, $tile)
            :                          $model->average_perc_for_lane($id_run, $position)
            ;
  my $title = $tile ? "Error percentage by cycle for Run $id_run, Position $position, Tile $tile."
            :         "Average Error percentage by cycle for Run $id_run, Position $position."
            ;

  my $args = {
    'width'        => $WIDTH,
    'height'       => $HEIGHT,
    'title'        => $title,
    'x_label_skip' => $X_LABEL_SKIP,
    'x_label'      => 'Cycle',
    'y_label'      => 'Percentage',
    'y_min_value'  => 0,
    'y_max_value'  => $MAX_ERROR_PERCENTAGE,
  };

  if ($thumbnail eq 'true') {
    $args->{height}  = $THUMB_HEIGHT;
    $args->{width}   = $THUMB_WIDTH;
    $args->{title}   = undef;
    $args->{x_label} = undef;
    $args->{y_label} = undef;
    $args->{legend}  = undef;
  }

  if ($pre_chastity) {
    $args->{legend} = ['pre-chastity', 'post-chastity'];
    $type = 'lines';
  }

  return $graph_obj->plotter($data, $args, $type, undef);
}

1;
__END__
=head1 NAME

npg_qc::view::errors_by_cycle

=head1 VERSION

$LastChangedRevision: 3386 $

=head1 SYNOPSIS

  my $o = npg_qc::view::errors_by_cycle->new({util => $util});

=head1 DESCRIPTION

=head1 SUBROUTINES/METHODS

=head2 list - handles the list view

=head2 list_ave_by_position - handles the list average by position

=head2 list_heatmaps - handles the list showing heatmaps

=head2 list_refactor - common code to put the id_run onto the model for list views

=head2 read_heatmap - handles rendering a png heatmap image for the information presented

=head2 read_png - handles rendering a png image for the information presented

=head2 read_ec_scale_png - handles rendering a png image for the scale of the heat gradients

=head2 read_heatmap_with_hover_ajax - handles rendering a return ajax html snippet which includes a map to hover over the rendered heatmap png

=head1 DIAGNOSTICS

=head1 CONFIGURATION AND ENVIRONMENT

=head1 DEPENDENCIES

strict
warnings
Carp
Readonly
English
npg_qc::view
npg_common::image_map
npg_common::image
npg_common::image::heatmap
npg_common::image::graph

=head1 INCOMPATIBILITIES

=head1 BUGS AND LIMITATIONS

=head1 AUTHOR

Andy Brown, E<lt>ajb@sanger.ac.ukE<gt>

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2008 GRL, by Andy Brown

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.4 or,
at your option, any later version of Perl 5 you may have available.

=cut
