#########
# Author:        ajb
# Maintainer:    $Author: gq1 $
# Created:       2008-10-15
# Last Modified: $Date: 2008-11-06 15:46:38 +0000 (Thu, 06 Nov 2008) $
# Id:            $Id: 20-view-run_tile.t 3386 2008-11-06 15:46:38Z gq1 $
# $HeadURL: svn+ssh://svn.internal.sanger.ac.uk/repos/svn/new-pipeline-dev/npg-qc/tags/release-4.0/t/20-view-run_tile.t $
#

use strict;
use warnings;
use Test::More  tests => 55 ;# 
use English qw(-no_match_vars);
use SangerPaths qw(core tracking badger ensembl);
use IO::Scalar;
use lib qw{t};
use t::util;
use npg_qc::model::run_tile;
use JSON qw(from_json);

our $VERSION = do { my ($r) = q$LastChangedRevision: 3386 $ =~ /(\d+)/mx; $r; };

use_ok('npg_qc::view::run_tile');
my $util = t::util->new({fixtures =>1});
{
  my $model = npg_qc::model::run_tile->new({util => $util});

  isa_ok($model, 'npg_qc::model::run_tile', '$model');

  my $view  = npg_qc::view::run_tile->new({
    util   => $util,
    model  => $model,
    aspect => 'list_json',
    action => 'list',
  });
  isa_ok($view, 'npg_qc::view::run_tile', '$view');
  is($view->decor(), 0, '$view->decor is 0');
  my $render;
  eval {
    $render = $view->render();
  };
  is($EVAL_ERROR, q{}, 'no croak on render');
  my $json;
  eval { $json = from_json($render); };
  is($EVAL_ERROR, q{}, 'JSON string parsed ok');
  is(scalar keys%{$json}, 1, '1 key as expecting error');
  is($json->{error}, 'no id_run provided', 'correct error message - no id_run provided');
}
{
  my $model = npg_qc::model::run_tile->new({util => $util});

  my $cgi = $util->cgi();
  $cgi->param('id_run', 10);

  my $view  = npg_qc::view::run_tile->new({
    util   => $util,
    model  => $model,
    aspect => 'list_json',
    action => 'list',
  });

  my $render;
  eval {
    $render = $view->render();
  };
  is($EVAL_ERROR, q{}, 'no croak on render');
  my $json;
  eval { $json = from_json($render); };
  is($EVAL_ERROR, q{}, 'JSON string parsed ok');
  is(scalar keys%{$json}, 5, '5 keys expected');
  is($json->{is_paired}, 1, 'is paired run');

  is($json->{id_run}, 10, 'correct id_run');
  is($json->{id_run_pair}, 11, 'correct id_run_pair');
  isa_ok($json->{read_1}, 'ARRAY', 'read_1 key');
  is(scalar@{$json->{read_1}}, 8, 'lanes returned ok');
  my $lane = $json->{read_1}->[0];
  isa_ok($lane, 'HASH', 'first lane');
  is(scalar keys%{$lane}, 2, '2 keys expected');
  is($lane->{lane}, 1, 'correct lane number');
  isa_ok($lane->{tiles}, 'ARRAY', 'tiles');
  is(scalar@{$lane->{tiles}}, 1, '1 tile in array');
  my $tile = $lane->{tiles}->[0];
  isa_ok($tile, 'HASH', 'tile');
  is(scalar keys%{$tile}, 4, '4 keys expected');
  is($tile->{tile}, 330, '$json->{run_tiles}->[0]->{tile} is correct');
  is($tile->{id_run_tile}, 12, 'position_data->{id_run_tile} is correct');
  my $qc_data = $tile->{tile_qc_data};
  isa_ok($qc_data, 'HASH', 'qc_data');
  is(scalar keys%{$qc_data}, 5, 'correct number of keys (5) for qc_data');
  my $position_data = $tile->{tile_position_data};
  isa_ok($position_data, 'HASH', 'position_data');
  is($position_data->{row}, 2, 'position_data->{row} is correct');
  is($position_data->{col}, 109, 'position_data->{col} is correct');
  is($position_data->{avg_newz}, q{}, 'position_data->{avg_newz} is correct');
}
{
  my $cgi = CGI->new();
  $util->{cgi} = $cgi;

  my $model = npg_qc::model::run_tile->new({util => $util});



  my $view  = npg_qc::view::run_tile->new({
    util   => $util,
    model  => $model,
    aspect => 'read_json',
    action => 'read',
  });

  my $render;
  eval {
    $render = $view->render();
  };
  is($EVAL_ERROR, q{}, 'no croak on render');
  my $json;
  eval { $json = from_json($render); };
  is($EVAL_ERROR, q{}, 'JSON string parsed ok');
  is(scalar keys%{$json}, 1, '1 key as expecting error');
  is($json->{error}, 'no id_run_tile provided', 'correct error message - no id_run_tile provided');
  
}
{
  my $model = npg_qc::model::run_tile->new({util => $util, id_run_tile => 10});

  my $view  = npg_qc::view::run_tile->new({
    util   => $util,
    model  => $model,
    aspect => 'read_json',
    action => 'read',
  });

  my $render;
  eval {
    $render = $view->render();
  };
  is($EVAL_ERROR, q{}, 'no croak on render');
  my $json;
  eval { $json = from_json($render); };
  is($EVAL_ERROR, q{}, 'JSON string parsed ok');

  is(scalar keys%{$json}, 1, 'USE OF ID_RUN_TILE: 1 key expected - single ended run');
  isa_ok($json->{read_one}, 'HASH', 'read_one');
  isa_ok($json->{read_one}->{position_info}, 'HASH', 'read_one->{position_info}');
  isa_ok($json->{read_one}->{tile_qc_data}, 'HASH', 'read_one->{tile_qc_data}');
  isa_ok($json->{read_one}->{errors_by_cycle}, 'ARRAY', 'read_one->{errors_by_cycle}');
  is($json->{read_one}->{position_info}->{id_run}, 3, 'correct id_run for read_one tile');
  is(scalar keys%{$json->{read_one}->{position_info}}, 7, '7 keys expected for position_info');
  is(scalar keys%{$json->{read_one}->{tile_qc_data}}, 8, '8 keys expected for tile_qc_data');
}
{
  my $model = npg_qc::model::run_tile->new({util => $util});
  my $cgi = $util->cgi();
  $cgi->param('id_run', 3);
  $cgi->param('position', 2);
  $cgi->param('tile', 7);

  my $view  = npg_qc::view::run_tile->new({
    util   => $util,
    model  => $model,
    aspect => 'read_json',
    action => 'read',
  });

  my $render;
  eval {
    $render = $view->render();
  };
  is($EVAL_ERROR, q{}, 'no croak on render');
  my $json;
  eval { $json = from_json($render); };
  is($EVAL_ERROR, q{}, 'JSON string parsed ok');

  is(scalar keys%{$json}, 1, 'USE OF ID_RUN, POSITION, TILE: 1 key expected - single ended run');
  isa_ok($json->{read_one}, 'HASH', 'read_one');
  isa_ok($json->{read_one}->{position_info}, 'HASH', 'read_one->{position_info}');
  isa_ok($json->{read_one}->{tile_qc_data}, 'HASH', 'read_one->{tile_qc_data}');
  isa_ok($json->{read_one}->{errors_by_cycle}, 'ARRAY', 'read_one->{errors_by_cycle}');
  is($json->{read_one}->{position_info}->{id_run}, 3, 'correct id_run for read_one tile');
  is(scalar keys%{$json->{read_one}->{position_info}}, 7, '7 keys expected for position_info');
  is(scalar keys%{$json->{read_one}->{tile_qc_data}}, 8, '8 keys expected for tile_qc_data');


}
