#########
# Author:        gq1
# Maintainer:    $Author: gq1 $
# Created:       2008-10-16
# Last Modified: $Date: 2008-11-06 15:46:38 +0000 (Thu, 06 Nov 2008) $
# Id:            $Id: 30-api-clean_repository.t 3386 2008-11-06 15:46:38Z gq1 $
# $HeadURL: svn+ssh://svn.internal.sanger.ac.uk/repos/svn/new-pipeline-dev/npg-qc/tags/release-4.0/t/30-api-clean_repository.t $
#

use strict;
use warnings;
use Test::More tests => 12;
use English qw(-no_match_vars);
use IO::Scalar;
use lib qw{t};
use t::api::util;
use t::useragent;
use SangerPaths qw(ensembl core badger trackingnpg tracking);

our $VERSION = do { my ($r) = q$LastChangedRevision: 3386 $ =~ /(\d+)/mx; $r; };

use_ok('npg_qc::api::clean_repository');

##
{
  my $ua_mock = {
    q{http://localhost:8080/cgi-bin/prodsoft/npg_qc/npg_qc/summary/;list_complete_data_xml}     => q{t/data/requests/cgi-bin/prodsoft/npg_qc/npg_qc/summary_complete_data.xml},
  };

  my $ua   = t::useragent->new({is_success => 1, mock => $ua_mock});
  my $util = t::api::util->new({dbh => 'dummy', fixtures => 0, useragent => $ua, parser => 0, base_uri => 'http://localhost:8080/cgi-bin/prodsoft/npg_qc/npg_qc/'});
  my $clean_repository = npg_qc::api::clean_repository->new({util => $util});

  isa_ok($clean_repository, 'npg_qc::api::clean_repository', '$clean_repository');
  
  
  my $web_target = 'summary/;list_complete_data_xml';
  my $xml;
  eval{
    $xml = $clean_repository->web_get_xml($web_target);
    1;
  };
  
  is($EVAL_ERROR, q{}, 'no croak for web_get_xml');
  
  like($xml, qr{<complete_run_summaries>}, "get xml");
  
 
  eval{
    $clean_repository->parse_runlist_xml($web_target);
    1;
  };
  
  is($EVAL_ERROR, q{}, 'no croak for parse_runlist_xml');

  is( scalar  keys %{$clean_repository->get_both_pair_run_complete()}, 7,'correct number of both pair run complete');
  is( scalar  keys %{$clean_repository->get_one_pair_run_complete()}, 4, 'correct number of one pair run complete');

  my $project = 'SLX_QC';
  my $file_ext_name = '*tar.bz2';
  eval{
    $clean_repository->retrieve_repository_file_list($project, $file_ext_name);
    1;
  };
  is($EVAL_ERROR, q{}, 'no croak to get the corresponding file list');
  
  #is(scalar @{$clean_repository->get_both_pair_run_complete_files()}, 7, 'correct file number of both pair run complete');
 # is(scalar @{$clean_repository->get_one_pair_run_complete_files()}, 4, 'correct file number of only one run of pair run complete');
}

##
{
  my $ua_mock = {};

  my $ua   = t::useragent->new({is_success => 0, mock => $ua_mock});
  my $util = t::api::util->new({dbh => 'dummy', fixtures => 0, useragent => $ua, parser => 0, base_uri => 'http://localhost:8080/cgi-bin/prodsoft/npg_qc/npg_qc/'});
  my $clean_repository = npg_qc::api::clean_repository->new({util => $util});

  isa_ok($clean_repository, 'npg_qc::api::clean_repository', '$clean_repository');
  
  
  my $web_target = 'summary/;list_complete_data_xml';
  my $xml;
  eval{
    $xml = $clean_repository->web_get_xml($web_target);
    1;
  };
  
  like($EVAL_ERROR, qr{failed\ to\ successfully\ get\ xml}, 'web_get_xml not successful');
  
  ok(!$xml, 'did not get xml');
  eval{
    $clean_repository->parse_runlist_xml($web_target);
    1;
  };
  
  like($EVAL_ERROR, qr{no\ runlist\ xml}, 'croak web get not successful');
  
}

1;
