#!/Users/ajb/dev/bin/perl -w
#########
# Author:        ajb
# Maintainer:    $Author: gq1 $
# Created:       2008-06-11
# Last Modified: $Date: 2008-11-06 15:46:38 +0000 (Thu, 06 Nov 2008) $
# Id:            $Id: 30-api-process_swift_output.t 3386 2008-11-06 15:46:38Z gq1 $
# $HeadURL: svn+ssh://svn.internal.sanger.ac.uk/repos/svn/new-pipeline-dev/npg-qc/tags/release-4.0/t/30-api-process_swift_output.t $
#

use strict;
use warnings;
use Test::More tests => 13;
use English qw(-no_match_vars);
use IO::Scalar;
use lib qw{t};
use t::api::util;

our $VERSION = do { my ($r) = q$LastChangedRevision: 3386 $ =~ /(\d+)/mx; $r; };

use_ok('npg_qc::api::process::swift_output');

my $runreport_file_url = q{t/data/staging/IL10/outgoing/080517_IL10_0747/Swift/20080606-183524/L004/Output/swift_299_runreport.txt};

my $report = q{PF Bases:  158076
PF Score:  115481
PF Reads:  4391
PF Unique: 3828

Non-PF Bases:  1091844
Non-PF Score:  696385
Non-PF Reads:  30329
Non-PF Unique: 22735


};

my $errors = q{0 1046
1 804
2 1438
3 849
4 1409


};

my $intensities = q{0  2203.14  2393.57  3251.37  4451.58
1  1684.61  2012.36  2874.1  3442.56
2  1925.49  2594.05  1821.15  2790.84
3  1795.79  2044.08  3181.54  3465.41
4  1804.12  2735.14  2236.91  3241.49


};

my $util = t::api::util->new({dbh => 'dummy', fixtures => 0, useragent => 0, parser => 0, base_uri => 0});

{
  my $swift_output_object = npg_qc::api::process::swift_output->new({util => $util});
  isa_ok($swift_output_object, 'npg_qc::api::process::swift_output', 'object created ok');
  $swift_output_object->set_tile(299);
  $swift_output_object->set_id_run(747);
  $swift_output_object->set_position(4);
  my $report_xml = $swift_output_object->report($report);
  is($report_xml, q{<?xml version="1.0" encoding="utf-8"?><swift_report id_run="747" tile="299" position="4" pf_bases="158076" pf_score="115481" pf_reads="4391" pf_unique="3828" non-pf_bases="1091844" non-pf_score="696385" non-pf_reads="30329" non-pf_unique="22735" />}, q{$swift_output_object->report($report)});
  my $pf_errors_xml = $swift_output_object->errors('pf_errors', $errors);
  is($pf_errors_xml, q{<?xml version="1.0" encoding="utf-8"?><pf_errors id_run="747" tile="299" position="4"><cycles><cycle number="1" errors="1046" /><cycle number="2" errors="804" /><cycle number="3" errors="1438" /><cycle number="4" errors="849" /><cycle number="5" errors="1409" /></cycles></pf_errors>}, q{$swift_output_object->errors('pf errors', $errors)});
  my $npf_errors_xml = $swift_output_object->errors('npf_errors', $errors);
  is($npf_errors_xml, q{<?xml version="1.0" encoding="utf-8"?><npf_errors id_run="747" tile="299" position="4"><cycles><cycle number="1" errors="1046" /><cycle number="2" errors="804" /><cycle number="3" errors="1438" /><cycle number="4" errors="849" /><cycle number="5" errors="1409" /></cycles></npf_errors>}, q{$swift_output_object->errors('npf errors', $errors)});
  my $all_intensities_xml = $swift_output_object->intensities('average_all_intensities', $intensities);
  is($all_intensities_xml, q{<?xml version="1.0" encoding="utf-8"?><average_all_intensities id_run="747" tile="299" position="4"><cycles><cycle number="1" a="2203.14" c="2393.57" g="3251.37" t="4451.58" /><cycle number="2" a="1684.61" c="2012.36" g="2874.1" t="3442.56" /><cycle number="3" a="1925.49" c="2594.05" g="1821.15" t="2790.84" /><cycle number="4" a="1795.79" c="2044.08" g="3181.54" t="3465.41" /><cycle number="5" a="1804.12" c="2735.14" g="2236.91" t="3241.49" /></cycles></average_all_intensities>}, q{$swift_output_object->intensities('average_all_intensities', $intensities)});
  my $called_intensities_xml = $swift_output_object->intensities('average_called_intensities', $intensities);
  is($called_intensities_xml, q{<?xml version="1.0" encoding="utf-8"?><average_called_intensities id_run="747" tile="299" position="4"><cycles><cycle number="1" a="2203.14" c="2393.57" g="3251.37" t="4451.58" /><cycle number="2" a="1684.61" c="2012.36" g="2874.1" t="3442.56" /><cycle number="3" a="1925.49" c="2594.05" g="1821.15" t="2790.84" /><cycle number="4" a="1795.79" c="2044.08" g="3181.54" t="3465.41" /><cycle number="5" a="1804.12" c="2735.14" g="2236.91" t="3241.49" /></cycles></average_called_intensities>}, q{$swift_output_object->intensities('average_called_intensities', $intensities)});
}
{
  my $swift_output_object = npg_qc::api::process::swift_output->new({util => $util});
  isa_ok($swift_output_object, 'npg_qc::api::process::swift_output', 'object created ok');
  eval{ $swift_output_object->process_file($runreport_file_url); };
  is($EVAL_ERROR, q{}, 'no croak on process file');
  is($swift_output_object->get_tile(),299,'process_file got correct tile');
  is($swift_output_object->get_id_run(),747,'process_file got correct id_run');
  is($swift_output_object->get_position(),4,'process_file got correct position');
  like($swift_output_object->get_file(),qr{\A\$Id:\ Reporting\.h\ 1943\ 2008-05-22\ 17:37:56Z\ nw3\ \$},'$swift_output_object->{file} has expected Id line at start');
}
1;
